package com.huigou.topsun.sap.purchaseOrder.controller;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.huigou.context.Operator;
import com.huigou.context.OrgUnit;
import com.huigou.topsun.sap.purchaseOrder.application.SapPurchaseOrderApplication;
import com.huigou.topsun.sap.purchaseOrder.application.SapPurchaseOrderItemApplication;
import com.huigou.topsun.sap.purchaseOrder.domain.SapPurchaseOrder;
import com.huigou.topsun.sap.purchaseOrder.domain.SapPurchaseOrderItem;
import com.huigou.topsun.sap.purchaseOrder.domain.query.SapPurchaseOrderQueryRequest;
import com.huigou.topsun.sap.purchaseOrder.domain.vo.SapPurchaseOrderVo;
import com.huigou.topsun.util.MyBaseUtil;
import com.huigou.uasp.annotation.ControllerMapping;
import com.huigou.uasp.annotation.SkipAuth;
import com.huigou.uasp.bmp.common.BizBillStatus;
import com.huigou.uasp.client.CommonController;
import com.huigou.util.SDO;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;

/**
 * @Auther: xin.lu
 * @Date: 2024/01/09/18:58
 * @Description:
 */
@Controller
@ControllerMapping("/sapPurchaseOrder")
public class SapPurchaseOrderController extends CommonController {
    @Resource
    private SapPurchaseOrderItemApplication sapPurchaseOrderItemApplication;
    @Resource
    private SapPurchaseOrderApplication sapPurchaseOrderApplication;
    @Override
    protected String getPagePath() {
        return "/biz/topsun/sap/purchaseOrder/";
    }

    @SkipAuth
    @RequestMapping( value = "/getSapPurchaseOrder")
    @ResponseBody
    public HashMap<String, Object> getSapPurchaseOrder(@RequestBody SapPurchaseOrderVo sapPurchaseOrderVo){

        this.sapPurchaseOrderApplication.saveSapPurchaseOrderVo(sapPurchaseOrderVo);
        HashMap<String, Object> messageMap = new HashMap<>();
        messageMap.put("Message_Status","S");
        messageMap.put("Message_Text","成功");
        return messageMap;
    }

    public String forwardSapPurchaseOrderList(){
        return forward("sapPurchaseOrderList");
    }

    public String slicedSapPurchaseOrderList(){
        SDO sdo = this.getSDO();
        SapPurchaseOrderQueryRequest queryRequest = sdo.toQueryRequest(SapPurchaseOrderQueryRequest.class);
        Map<String, Object> map = sapPurchaseOrderApplication.slicedSapPurchaseOrderList(queryRequest);
        return toResult(map);
    }

    public String showSapPurchaseOrderDetail(){
        SDO sdo = this.getSDO();
        String id = sdo.getBizId();
        SapPurchaseOrder sapPurchaseOrder = sapPurchaseOrderApplication.loadSapPurchaseOrder(id);
        SapPurchaseOrderItem purchaseOrderItem = sapPurchaseOrderItemApplication.getPurchaseOrderItem(sapPurchaseOrder.getId());
        ObjectMapper objectMapper = new ObjectMapper();
        //禁止日期类型转换为时间戳
        objectMapper.configure(SerializationFeature.WRITE_DATES_AS_TIMESTAMPS, false);
        objectMapper.setDateFormat(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss.SSS"));
        Map<String, Object> map = objectMapper.convertValue(sapPurchaseOrder, Map.class);
        map.putAll(MyBaseUtil.convertToMap(purchaseOrderItem));
        return forward("sapPurchaseOrderDetail",map);
    }
}
